#!/usr/bin/env python

"""
usage: pyre_client01.py [-h]

synopsis:
  A simple Pyre client

optional arguments:
  -h, --help  show this help message and exit

examples:
  python client01.py
"""

#
# imports
from __future__ import print_function
import sys
import argparse
import pyre

if sys.version_info.major == 2:
    input = raw_input


#
# Global variables

Node_name = 'rook'
Node_value = 'rook client'
Group_name = 'group1'


#
# Private functions

def dbg_msg(options, msg):
    """Print a message if verbose is on."""
    if options.verbose:
        print(msg)


#
# Exported functions

def run(opts):
    node = pyre.Pyre(Node_name)
    node.set_header(Node_name, Node_value)
    node.start()
    node.join(Group_name)
    idx = 0
    while True:
        try:
            print('ready to receive')
            while True:
                data = node.recv()
                if data[0] == b'SHOUT':
                    break
            print('{}. data: {}'.format(idx, data))
            response = input('press Enter or "q"/"quit" to leave: ')
            if response in ('q', 'quit'):
                break
            idx += 1
        except KeyboardInterrupt:
            break
    print('\ncleaning up and leaving')
    node.leave(Group_name)
    node.stop()


def main():
    description = """\
synopsis:
  A simple Pyre client
"""
    epilog = """\
examples:
  python client01.py
"""
    parser = argparse.ArgumentParser(
        description=description,
        epilog=epilog,
        formatter_class=argparse.RawDescriptionHelpFormatter,
    )
#    parser.add_argument(
#        "command",
#        help="A command, one of: getlist, getone, add, update, delete"
#    )
#    parser.add_argument(
#        "-a", "--args",
#        help="Arguments: (1) task name or (2) form parameters"
#    )
#    parser.add_argument(
#        "-v", "--verbose",
#        action="store_true",
#        help="Print messages during actions.",
#    )
    options = parser.parse_args()
    run(options)


if __name__ == '__main__':
    # import pdb; pdb.set_trace()
    # import ipdb; ipdb.set_trace()
    main()
